<?php
namespace PrestaShop\Module\PolarisPrestaConnector;

use PolarisPrestaConnector;

class Upgrade_0_1 {
    /**
     * Complète la liste des couleurs
     */
    public function upgradeColorLists(PolarisPrestaConnector $module)
    {
        include __DIR__ . '/colors.php';
        
        $colorMap = $module->getCfg()->get(SyncConfiguration::CFG_COLOR_MAP, []);

        if (!isset($colorMap["strict"]))
            $colorMap["strict"] = [];

        // Pour chaque couleur existante dans la liste des couleurs
        // on va regarder si elle est défini dans la map des couleurs
        // si ce n'est pas le cas ou qu'elle est vide, alors on map
        // la couleur sur elle-même
        foreach ($colorDefinitions as $color => $value) {
            if (!isset($colorMap["strict"][$color]) || empty($colorMap["strict"][$color]))
                $colorMap["strict"][$color] = $value;
        }

        // Sauvegarde de la nouvelle map
        $module->getCfg()->set(SyncConfiguration::CFG_COLOR_MAP, $colorMap);
    }

    /**
     * Déclenche la mise à jour de la base de données du module
     */
    public function upgrade(PolarisPrestaConnector $module, $db)
    {
        // On créer la table de configuration du module
        if (!$db->execute('
            CREATE TABLE IF NOT EXISTS `' . $module->TblPrefix . 'configuration` (
                `key` VARCHAR(255) NOT NULL,
                `value` JSON,
                PRIMARY KEY (`key`)
            ) ENGINE=' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8;'))
             throw new \Exception('Erreur lors de la création de la table de configuration du module');

        // On créer une table de mappage pour les photos
        if (!$db->execute('
            CREATE TABLE IF NOT EXISTS `' . $module->TblPrefix . 'image` (
                `photo` VARCHAR(255) NOT NULL,
                `id_product` INT(10) UNSIGNED NOT NULL,
                `id_image` INT(10) UNSIGNED NOT NULL,
                PRIMARY KEY (`photo`)
            ) ENGINE=' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8;'))
             throw new \Exception('Erreur lors de la création de la table de mappage des photos');

        // On créer la clé étrangère entre la table image et la table image de prestashop sur id_image si elle n'existe pas
        if (!$db->execute('ALTER TABLE `' . $module->TblPrefix . 'image` ADD CONSTRAINT FOREIGN KEY (`id_product`) REFERENCES `' . _DB_PREFIX_ . 'product` (`id_product`) ON DELETE CASCADE;'))
             throw new \Exception('Erreur lors de la création de la clé étrangère entre la table image et la table product de prestashop');
        if (!$db->execute('ALTER TABLE `' . $module->TblPrefix . 'image` ADD CONSTRAINT FOREIGN KEY (`id_image`) REFERENCES `' . _DB_PREFIX_ . 'image` (`id_image`) ON DELETE CASCADE;'))
             throw new \Exception('Erreur lors de la création de la clé étrangère entre la table image et la table image de prestashop');

        // On créer une table pour les stocks
        // Qui associe à un couple "id_product_attribute, store_code", une quantité en stock et une quantité en commande
        if (!$db->execute('
            CREATE TABLE IF NOT EXISTS `' . $module->TblPrefix . 'stocks` (
                `id_product` INT(10) UNSIGNED NOT NULL,
                `id_product_attribute` INT(10) UNSIGNED NOT NULL,
                `store_code` VARCHAR(20) NOT NULL,
                `qty` INT(10) UNSIGNED NOT NULL,                
                PRIMARY KEY (`id_product_attribute`, `store_code`)
            ) ENGINE=' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8;'))
             throw new \Exception('Erreur lors de la création de la table de mappage des stocks');

        // On crée la clé étrangère qui lie le id_product à la table product
        if (!$db->execute('ALTER TABLE `' . $module->TblPrefix . 'stocks` ADD CONSTRAINT FOREIGN KEY (`id_product`) REFERENCES `' . _DB_PREFIX_ . 'product` (`id_product`) ON DELETE CASCADE;'))
             throw new \Exception('Erreur lors de la création de la clé étrangère entre la table stock et la table product de prestashop');

        // On crée la clé étrangère qui lie le id_product_attribute à la table product_attribute
        if (!$db->execute('ALTER TABLE `' . $module->TblPrefix . 'stocks` ADD CONSTRAINT FOREIGN KEY (`id_product_attribute`) REFERENCES `' . _DB_PREFIX_ . 'product_attribute` (`id_product_attribute`) ON DELETE CASCADE;'))
             throw new \Exception('Erreur lors de la création de la clé étrangère entre la table stock et la table product_attribute de prestashop');

        // Upgrade de la liste des couleurs
        $this->upgradeColorLists($module);
    }
}